@@ -301,20 +301,121 @@ map.feature <- function(languages,
 
   # create a palette ---------------------------------------------------------
   set.seed(42)
+
+  # library(Polychrome) # v1.5.1
+  # set.seed(723451) # for reproducibility
+  # firstpal <- createPalette(100, c("#1f77b4",
+  #                                  "#ff7f0e",
+  #                                  "#2ca02c",
+  #                                  "#d62728",
+  #                                  "#9467bd",
+  #                                  "#8c564b",
+  #                                  "#e377c2",
+  #                                  "#7f7f7f",
+  #                                  "#17becf"), M=1000)
+  # swatch(firstpal)
+
   my_colors <-
-    c(
-      "#1f77b4",
-      "#ff7f0e",
-      "#2ca02c",
-      "#d62728",
-      "#9467bd",
-      "#8c564b",
-      "#e377c2",
-      "#7f7f7f",
-      "#17becf",
-      sample(grDevices::colors()[!grepl("ivory|azure|white|gray|grey|black|pink|1",
-                                        grDevices::colors())])
-    )
+    c("#3B8BC6",
+      "#F78716",
+      "#35A532",
+      "#E62651",
+      "#8D63B9",
+      "#8E5D4D",
+      "#EB88CD",
+      "#93898C",
+      "#2ED1E5",
+      "#F3DD0D",
+      "#F135FF",
+      "#3832F2",
+      "#F61CAF",
+      "#35FE2E",
+      "#D9E5A4",
+      "#E5717D",
+      "#0DE0B9",
+      "#E7A962",
+      "#C9D8FC",
+      "#1C8062",
+      "#AF5AF5",
+      "#ADE535",
+      "#BDEDDB",
+      "#BF00A8",
+      "#358DFC",
+      "#85224F",
+      "#FDD4C8",
+      "#E97FF8",
+      "#22FBA1",
+      "#998932",
+      "#9DEEAA",
+      "#E7B4F8",
+      "#5697A4",
+      "#FB72B0",
+      "#F89FB8",
+      "#E72A7E",
+      "#A1B116",
+      "#A872A1",
+      "#628322",
+      "#AEB3FE",
+      "#6E6E92",
+      "#FDD6F1",
+      "#6C45C2",
+      "#FD0DE6",
+      "#81855D",
+      "#F5DA89",
+      "#7DF156",
+      "#FC9B6D",
+      "#00FAF4",
+      "#49C4BB",
+      "#9491FC",
+      "#8DD0FD",
+      "#F5C232",
+      "#22A469",
+      "#A9DB77",
+      "#BF0073",
+      "#E0E0E0",
+      "#D1DF0D",
+      "#DAB386",
+      "#EC704B",
+      "#923B9B",
+      "#BBC6A6",
+      "#C28A96",
+      "#D0A0FE",
+      "#AF32C7",
+      "#851CF1",
+      "#F5A71C",
+      "#BE7169",
+      "#CF7ED6",
+      "#9EE5ED",
+      "#32A7F5",
+      "#F958C4",
+      "#C1479B",
+      "#6EE582",
+      "#EC6DDC",
+      "#E04953",
+      "#6E8D81",
+      "#A79ECE",
+      "#D735D8",
+      "#E9A7CE",
+      "#3D6594",
+      "#FA0D7D",
+      "#FD9E92",
+      "#7058E9",
+      "#A45A77",
+      "#7CD8AF",
+      "#F02ECB",
+      "#4063AD",
+      "#D535FF",
+      "#1C7A2E",
+      "#6D9FC5",
+      "#B8AA22",
+      "#B468E0",
+      "#A44F8E",
+      "#CA425C",
+      "#906CA8",
+      "#B2DAA5",
+      "#AF4D4B",
+      "#16C5EF",
+      "#CBB9B0")
   if (is.null(color)) {
     if (is.numeric(mapfeat.df$features)) {
       pal <-
